[libdvbpsi-devel] Use a standard decode function name in dr_a0

Daniel Kamil Kozar git at videolan.org
Mon Aug 24 12:54:45 CEST 2015


libdvbpsi | branch: master | Daniel Kamil Kozar <dkk089 at gmail.com> | Sun Jul 26 04:09:40 2015 +0200| [97fe482be4bc4ac38a5cda5e9360ff833a710e1d] | committer: Jean-Paul Saman

Use a standard decode function name in dr_a0

(modified by Jean-Paul Saman <jpsaman at videolan.org>)
Added wrapper function to map dvbpsi_ExtendedChannelNameDr onto dvbpsi_DecodeExtendedChannelNameDr and update documentation.

(cherry picked from commit 7841440f06d01e2857fac3db1be07909446bcad4)
Signed-off-by: Jean-Paul Saman <jpsaman at videolan.org>

> http://git.videolan.org/gitweb.cgi/libdvbpsi.git/?a=commit;h=97fe482be4bc4ac38a5cda5e9360ff833a710e1d
---

 src/descriptors/dr_a0.c |   10 +++++++++-
 src/descriptors/dr_a0.h |   16 ++++++++++++++--
 2 files changed, 23 insertions(+), 3 deletions(-)

diff --git a/src/descriptors/dr_a0.c b/src/descriptors/dr_a0.c
index 8004aea..c2bbbce 100644
--- a/src/descriptors/dr_a0.c
+++ b/src/descriptors/dr_a0.c
@@ -40,10 +40,18 @@ Decode Extended Channel Name Descriptor.
 #include "dr_a0.h"
 
 /*****************************************************************************
- * dvbpsi_ExtendedChannelNameDr
+ * dvbpsi_ExtendedChannelNameDr - deprecated
  *****************************************************************************/
 dvbpsi_extended_channel_name_dr_t *dvbpsi_ExtendedChannelNameDr(dvbpsi_descriptor_t *p_descriptor)
 {
+    return dvbpsi_DecodeExtendedChannelNameDr(p_descriptor);
+}
+
+/*****************************************************************************
+ * dvbpsi_DecodeExtendedChannelNameDr
+ *****************************************************************************/
+dvbpsi_extended_channel_name_dr_t *dvbpsi_DecodeExtendedChannelNameDr(dvbpsi_descriptor_t *p_descriptor)
+{
     dvbpsi_extended_channel_name_dr_t *p_decoded;
 
     /* Check the tag */
diff --git a/src/descriptors/dr_a0.h b/src/descriptors/dr_a0.h
index dbdfaad..c009e6c 100644
--- a/src/descriptors/dr_a0.h
+++ b/src/descriptors/dr_a0.h
@@ -55,11 +55,11 @@ typedef struct dvbpsi_extended_channel_name_dr_s
 }dvbpsi_extended_channel_name_dr_t;
 
 /*****************************************************************************
- * dvbpsi_ExtendedChannelNameDr
+ * dvbpsi_ExtendedChannelNameDr - deprecated
  *****************************************************************************/
 /*!
  * \fn dvbpsi_extended_channel_name_dr_t dvbpsi_ExtendedChannelNameDr(dvbpsi_descriptor_t *p_descriptor)
  * \brief Decode a Extended Channel Name descriptor (tag 0xA0)
  * \param p_descriptor Raw descriptor to decode.
  * \return NULL if the descriptor could not be decoded or a pointer to a
  *         dvbpsi_extended_channel_name_dr_t structure.
@@ -67,6 +67,18 @@ typedef struct dvbpsi_extended_channel_name_dr_s
 __attribute__((deprecated))
 dvbpsi_extended_channel_name_dr_t *dvbpsi_ExtendedChannelNameDr(dvbpsi_descriptor_t *p_descriptor);
 
+/*****************************************************************************
+ * dvbpsi_DecodeExtendedChannelNameDr
+ *****************************************************************************/
+/*!
+ * \fn dvbpsi_extended_channel_name_dr_t dvbpsi_DecodeExtendedChannelNameDr(dvbpsi_descriptor_t *p_descriptor)
+ * \brief Decode a Extended Channel Name descriptor (tag 0xA0)
+ * \param p_descriptor Raw descriptor to decode.
+ * \return NULL if the descriptor could not be decoded or a pointer to a
+ *         dvbpsi_extended_channel_name_dr_t structure.
+ */
+dvbpsi_extended_channel_name_dr_t *dvbpsi_DecodeExtendedChannelNameDr(dvbpsi_descriptor_t *p_descriptor);
+
 #ifdef __cplusplus
 }
 #endif
@@ -55,11 +55,11 @@ typedef struct dvbpsi_extended_channel_name_dr_s
 /*!
  * \fn dvbpsi_extended_channel_name_dr_t dvbpsi_ExtendedChannelNameDr(dvbpsi_descriptor_t *p_descriptor)
- * \brief Decode a Extended Channel Name descriptor (tag 0xA0)
+ * \brief Function is deprecated use dvbpsi_DecodeExtendedChannelNameDr instead.
  * \param p_descriptor Raw descriptor to decode.
  * \return NULL if the descriptor could not be decoded or a pointer to a



More information about the libdvbpsi-devel mailing list